@@ -17,9 +17,6 @@
  */
 
 /* M_PI is defined in math.h in the case of Microsoft Visual C++ */
-#if defined(_WIN32)
-#define _USE_MATH_DEFINES
-#endif
 
 #include <cairommconfig.h>
 #include <cairomm/context.h>
@@ -166,14 +163,14 @@ void Context::set_dash(const std::valarray<double>& dashes, double offset)
 void Context::set_dash(const std::vector<double>& dashes, double offset)
 {
   cairo_set_dash(cobj(),
-    (dashes.empty() ? 0 : &dashes[0]),
+    (dashes.empty() ? nullptr : &dashes[0]),
     dashes.size(), offset);
   check_object_status_and_throw_exception(*this);
 }
 
 void Context::unset_dash()
 {
-  cairo_set_dash(cobj(), NULL, 0, 0.0);
+  cairo_set_dash(cobj(), nullptr, 0, 0.0);
   check_object_status_and_throw_exception(*this);
 }
 
@@ -521,9 +518,9 @@ void Context::show_text_glyphs(const std::string& utf8,
                                TextClusterFlags cluster_flags)
 {
   cairo_show_text_glyphs(cobj(), utf8.c_str(), utf8.size(),
-                         (glyphs.empty() ? 0 : &glyphs[0]),
+                         (glyphs.empty() ? nullptr : &glyphs[0]),
                          glyphs.size(),
-                         (clusters.empty() ? 0 : &clusters[0]),
+                         (clusters.empty() ? nullptr : &clusters[0]),
                          clusters.size(),
                          static_cast<cairo_text_cluster_flags_t>(cluster_flags));
   check_object_status_and_throw_exception(*this);
@@ -532,7 +529,7 @@ void Context::show_text_glyphs(const std::string& utf8,
 void Context::show_glyphs(const std::vector<Glyph>& glyphs)
 {
   cairo_show_glyphs(cobj(),
-    const_cast<cairo_glyph_t*>((glyphs.empty() ? 0 : &glyphs[0])),
+    const_cast<cairo_glyph_t*>((glyphs.empty() ? nullptr : &glyphs[0])),
     glyphs.size());
   check_object_status_and_throw_exception(*this);
 }
@@ -572,7 +569,7 @@ void Context::get_text_extents(const std::string& utf8, TextExtents& extents) co
 void Context::get_glyph_extents(const std::vector<Glyph>& glyphs, TextExtents& extents) const
 {
   cairo_glyph_extents(const_cast<cobject*>(cobj()),
-                      const_cast<cairo_glyph_t*>(glyphs.empty() ? 0 : &glyphs[0]),
+                      const_cast<cairo_glyph_t*>(glyphs.empty() ? nullptr : &glyphs[0]),
                       glyphs.size(), &extents);
   check_object_status_and_throw_exception(*this);
 }
@@ -586,7 +583,7 @@ void Context::text_path(const std::string& utf8)
 void Context::glyph_path(const std::vector<Glyph>& glyphs)
 {
   cairo_glyph_path(cobj(),
-    const_cast<cairo_glyph_t*>(glyphs.empty() ? 0 : &glyphs[0]),
+    const_cast<cairo_glyph_t*>(glyphs.empty() ? nullptr : &glyphs[0]),
     glyphs.size());
   check_object_status_and_throw_exception(*this);
 }
@@ -635,6 +632,21 @@ RefPtr<const Pattern> Context::get_source() const
   return get_pattern_wrapper(pattern);
 }
 
+RefPtr<SurfacePattern> Context::get_source_for_surface()
+{
+  auto pattern = cairo_get_source(cobj());
+  check_object_status_and_throw_exception(*this);
+  auto pattern_type = cairo_pattern_get_type(pattern);
+  if (pattern_type != CAIRO_PATTERN_TYPE_SURFACE)
+    return {};
+  return make_refptr_for_instance<SurfacePattern>(new SurfacePattern(pattern, false /* does not have reference */));
+}
+
+RefPtr<const SurfacePattern> Context::get_source_for_surface() const
+{
+  return const_cast<Context*>(this)->get_source_for_surface();
+}
+
 double Context::get_tolerance() const
 {
   const auto result = cairo_get_tolerance(const_cast<cobject*>(cobj()));
